"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShikiProvider = ShikiProvider;
exports.useShiki = useShiki;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _react = _interopRequireWildcard(require("react"));
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/* eslint-disable no-console */

const DEBUG = true;
function log(...args) {
  if (DEBUG) console.log('[ShikiProvider]', ...args);
}
const ShikiContext = /*#__PURE__*/(0, _react.createContext)(null);
function ShikiProvider({
  children,
  initialLanguages,
  initialThemes
}) {
  const [highlighter, setHighlighter] = (0, _react.useState)(null);
  const [isReady, setIsReady] = (0, _react.useState)(false);
  const [error, setError] = (0, _react.useState)(null);
  (0, _react.useEffect)(() => {
    let mounted = true;
    const initHighlighter = async () => {
      try {
        log('Initializing highlighter...');
        const engine = (0, _engineJavascript.createJavaScriptRegexEngine)({
          forgiving: true,
          cache: new Map()
        });
        const instance = await (0, _core.createHighlighterCore)({
          engine
        });

        // Load themes first
        log('Loading themes...');
        for (const theme of initialThemes) {
          await instance.loadTheme(theme);
        }

        // Then load languages
        log('Loading languages...');
        for (const lang of initialLanguages) {
          await instance.loadLanguage(lang);
        }
        if (mounted) {
          setHighlighter(instance);
          setIsReady(true);
          log('Highlighter ready with:', {
            languages: instance.getLoadedLanguages(),
            themes: instance.getLoadedThemes()
          });
        }
      } catch (err) {
        console.error('Failed to initialize highlighter:', err);
        if (mounted) {
          setError(err instanceof Error ? err : new Error('Failed to initialize highlighter'));
        }
      }
    };
    initHighlighter();
    return () => {
      mounted = false;
    };
  }, []); // Intentionally empty deps since initialLanguages/Themes should be stable

  const value = (0, _react.useMemo)(() => ({
    highlighter,
    isReady,
    error,
    getLoadedLanguages: () => highlighter?.getLoadedLanguages() || [],
    getLoadedThemes: () => highlighter?.getLoadedThemes() || []
  }), [highlighter, isReady, error]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(ShikiContext.Provider, {
    value: value,
    children: children
  });
}
function useShiki() {
  const context = (0, _react.useContext)(ShikiContext);
  if (!context) {
    throw new Error('useShiki must be used within a ShikiProvider');
  }
  return context;
}
//# sourceMappingURL=SyntaxContext.js.map