"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SyntaxHighlighter = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _SyntaxContext = require("./SyntaxContext");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const styles = _reactNative.StyleSheet.create({
  container: {
    flex: 1
  },
  line: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  }
});
const SyntaxHighlighter = exports.SyntaxHighlighter = /*#__PURE__*/(0, _react.memo)(({
  code,
  language,
  theme = 'github-dark',
  fontSize = 14
}) => {
  const {
    highlighter,
    isReady
  } = (0, _SyntaxContext.useShiki)();
  const [tokens, setTokens] = (0, _react.useState)([]);
  const [error, setError] = (0, _react.useState)(null);
  const highlight = (0, _react.useCallback)(async () => {
    if (!highlighter || !isReady) return;
    try {
      // Get loaded languages for validation
      const loadedLangs = highlighter.getLoadedLanguages();
      const normalizedLang = language.toLowerCase();

      // Use text if language isn't loaded
      const effectiveLang = loadedLangs.includes(normalizedLang) ? normalizedLang : 'text';
      const themeName = typeof theme === 'string' ? theme : theme.name;
      const results = highlighter.codeToTokensBase(code, {
        lang: effectiveLang,
        theme: themeName
      });
      setTokens(results);
      setError(null);
    } catch (err) {
      console.error('Highlighting error:', err);
      setError(err instanceof Error ? err.message : 'Failed to highlight code');
    }
  }, [code, language, theme, highlighter, isReady]);
  (0, _react.useEffect)(() => {
    highlight();
  }, [highlight]);
  if (!isReady) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: styles.container,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
        style: {
          fontSize
        },
        children: code
      })
    });
  }
  if (error) {
    return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
      style: styles.container,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
        style: {
          color: 'red'
        },
        children: error
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
        style: {
          fontSize
        },
        children: code
      })]
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    horizontal: true,
    style: styles.container,
    contentContainerStyle: {
      padding: 10
    },
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      children: tokens.map((line, i) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: styles.line,
        children: line.map((token, j) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
          style: {
            color: token.color,
            fontSize,
            ...(token.fontStyle && token.fontStyle & 1 && {
              fontStyle: 'italic'
            }),
            ...(token.fontStyle && token.fontStyle & 2 && {
              fontWeight: 'bold'
            })
          },
          children: token.content
        }, `${i}-${j}`))
      }, i))
    })
  });
});
//# sourceMappingURL=SyntaxHighlighter.js.map