"use strict";

/* eslint-disable no-console */

import { createHighlighterCore } from '@shikijs/core';
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript';
import React, { createContext, useContext, useEffect, useMemo, useState } from 'react';
import { jsx as _jsx } from "react/jsx-runtime";
const DEBUG = true;
function log(...args) {
  if (DEBUG) console.log('[ShikiProvider]', ...args);
}
const ShikiContext = /*#__PURE__*/createContext(null);
export function ShikiProvider({
  children,
  initialLanguages,
  initialThemes
}) {
  const [highlighter, setHighlighter] = useState(null);
  const [isReady, setIsReady] = useState(false);
  const [error, setError] = useState(null);
  useEffect(() => {
    let mounted = true;
    const initHighlighter = async () => {
      try {
        log('Initializing highlighter...');
        const engine = createJavaScriptRegexEngine({
          forgiving: true,
          cache: new Map()
        });
        const instance = await createHighlighterCore({
          engine
        });

        // Load themes first
        log('Loading themes...');
        for (const theme of initialThemes) {
          await instance.loadTheme(theme);
        }

        // Then load languages
        log('Loading languages...');
        for (const lang of initialLanguages) {
          await instance.loadLanguage(lang);
        }
        if (mounted) {
          setHighlighter(instance);
          setIsReady(true);
          log('Highlighter ready with:', {
            languages: instance.getLoadedLanguages(),
            themes: instance.getLoadedThemes()
          });
        }
      } catch (err) {
        console.error('Failed to initialize highlighter:', err);
        if (mounted) {
          setError(err instanceof Error ? err : new Error('Failed to initialize highlighter'));
        }
      }
    };
    initHighlighter();
    return () => {
      mounted = false;
    };
  }, []); // Intentionally empty deps since initialLanguages/Themes should be stable

  const value = useMemo(() => ({
    highlighter,
    isReady,
    error,
    getLoadedLanguages: () => highlighter?.getLoadedLanguages() || [],
    getLoadedThemes: () => highlighter?.getLoadedThemes() || []
  }), [highlighter, isReady, error]);
  return /*#__PURE__*/_jsx(ShikiContext.Provider, {
    value: value,
    children: children
  });
}
export function useShiki() {
  const context = useContext(ShikiContext);
  if (!context) {
    throw new Error('useShiki must be used within a ShikiProvider');
  }
  return context;
}
//# sourceMappingURL=SyntaxContext.js.map