"use strict";

import React, { memo, useCallback, useEffect, useState } from 'react';
import { ScrollView, StyleSheet, Text, View } from 'react-native';
import { useShiki } from './SyntaxContext';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const styles = StyleSheet.create({
  container: {
    flex: 1
  },
  line: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  }
});
export const SyntaxHighlighter = /*#__PURE__*/memo(({
  code,
  language,
  theme = 'github-dark',
  fontSize = 14
}) => {
  const {
    highlighter,
    isReady
  } = useShiki();
  const [tokens, setTokens] = useState([]);
  const [error, setError] = useState(null);
  const highlight = useCallback(async () => {
    if (!highlighter || !isReady) return;
    try {
      // Get loaded languages for validation
      const loadedLangs = highlighter.getLoadedLanguages();
      const normalizedLang = language.toLowerCase();

      // Use text if language isn't loaded
      const effectiveLang = loadedLangs.includes(normalizedLang) ? normalizedLang : 'text';
      const themeName = typeof theme === 'string' ? theme : theme.name;
      const results = highlighter.codeToTokensBase(code, {
        lang: effectiveLang,
        theme: themeName
      });
      setTokens(results);
      setError(null);
    } catch (err) {
      console.error('Highlighting error:', err);
      setError(err instanceof Error ? err.message : 'Failed to highlight code');
    }
  }, [code, language, theme, highlighter, isReady]);
  useEffect(() => {
    highlight();
  }, [highlight]);
  if (!isReady) {
    return /*#__PURE__*/_jsx(View, {
      style: styles.container,
      children: /*#__PURE__*/_jsx(Text, {
        style: {
          fontSize
        },
        children: code
      })
    });
  }
  if (error) {
    return /*#__PURE__*/_jsxs(View, {
      style: styles.container,
      children: [/*#__PURE__*/_jsx(Text, {
        style: {
          color: 'red'
        },
        children: error
      }), /*#__PURE__*/_jsx(Text, {
        style: {
          fontSize
        },
        children: code
      })]
    });
  }
  return /*#__PURE__*/_jsx(ScrollView, {
    horizontal: true,
    style: styles.container,
    contentContainerStyle: {
      padding: 10
    },
    children: /*#__PURE__*/_jsx(View, {
      children: tokens.map((line, i) => /*#__PURE__*/_jsx(View, {
        style: styles.line,
        children: line.map((token, j) => /*#__PURE__*/_jsx(Text, {
          style: {
            color: token.color,
            fontSize,
            ...(token.fontStyle && token.fontStyle & 1 && {
              fontStyle: 'italic'
            }),
            ...(token.fontStyle && token.fontStyle & 2 && {
              fontWeight: 'bold'
            })
          },
          children: token.content
        }, `${i}-${j}`))
      }, i))
    })
  });
});
//# sourceMappingURL=SyntaxHighlighter.js.map